"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Converter = void 0;
const autobind_decorator_1 = require("autobind-decorator");
const Container_1 = require("../Container");
const fs = require("fs");
const rimraf_1 = require("rimraf");
const yazl_1 = require("yazl");
/**
 * Converts the TransXChange input stream to a GTFS zip output stream
 */
let Converter = class Converter {
    constructor(inputStream, gtfsFiles) {
        this.inputStream = inputStream;
        this.gtfsFiles = gtfsFiles;
    }
    /**
     * Load the XML into memory, convert it to JSON, then a TransXChange object and the pass that to each of the GTFS file
     * factory methods.
     */
    async process(input, output) {
        if (input.length === 0 || output === undefined) {
            throw Error("Invalid number of arguments");
        }
        this.init();
        this.pushInputFiles(input);
        const streams = Object
            .keys(this.gtfsFiles)
            .map(file => this.gtfsFiles[file].pipe(fs.createWriteStream(Container_1.Container.TMP + file)));
        await this.streamsFinished(streams);
        const zipFile = new yazl_1.ZipFile();
        for (const file in this.gtfsFiles) {
            zipFile.addFile(Container_1.Container.TMP + file, file);
        }
        zipFile.end();
        await this.writeToFile(zipFile.outputStream, output);
        console.log("Complete.");
        console.log(`Memory usage: ${Math.round((process.memoryUsage().heapUsed / 1024 / 1024) * 100) / 100} MB`);
    }
    init() {
        if (fs.existsSync(Container_1.Container.TMP)) {
            (0, rimraf_1.sync)(Container_1.Container.TMP);
        }
        fs.mkdirSync(Container_1.Container.TMP);
    }
    pushInputFiles(input) {
        for (const file of input) {
            this.inputStream.write(file);
        }
        this.inputStream.end();
    }
    streamsFinished(streams) {
        const promises = streams.map(s => new Promise((resolve, reject) => {
            s.on("finish", resolve);
            s.on("error", reject);
        }));
        return Promise.all(promises);
    }
    writeToFile(outputStream, output) {
        const stream = outputStream.pipe(fs.createWriteStream(output));
        return new Promise((resolve, reject) => {
            stream.on("close", resolve);
            stream.on("error", reject);
        });
    }
};
Converter = __decorate([
    autobind_decorator_1.default
], Converter);
exports.Converter = Converter;
