"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AgencyStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
/**
 * Extract the agencies from the TransXChange objects
 */
class AgencyStream extends GTFSFileStream_1.GTFSFileStream {
    constructor() {
        super(...arguments);
        this.agenciesSeen = {};
        this.header = "agency_id,agency_name,agency_url,agency_timezone,agency_lang,agency_phone,agency_fare_url";
        this.agencyUrl = process.env.AGENCY_URL || "http://agency.com";
        this.agencyTimezone = process.env.AGENCY_TIMEZONE || "Europe/London";
        this.agencyLang = process.env.AGENCY_LANG || "en";
    }
    transform(data) {
        for (const operatorId of Object.keys(data.Operators)) {
            if (!this.agenciesSeen[operatorId]) {
                const operator = data.Operators[operatorId];
                const agencyName = operator.OperatorNameOnLicence || operator.OperatorShortName;
                this.pushLine(operatorId, agencyName, this.agencyUrl, this.agencyTimezone, this.agencyLang, "", "");
                this.agenciesSeen[operatorId] = true;
            }
        }
    }
}
exports.AgencyStream = AgencyStream;
