"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CalendarDatesStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
const js_joda_1 = require("js-joda");
/**
 * Extract the calendars dates from the TransXChange journeys
 */
class CalendarDatesStream extends GTFSFileStream_1.GTFSFileStream {
    constructor() {
        super(...arguments);
        this.datesSeen = {};
        this.dateFormatter = js_joda_1.DateTimeFormatter.ofPattern("yyyyMMdd");
        this.header = "service_id,date,exception_type";
    }
    transform(journey) {
        if (!this.datesSeen[journey.calendar.id]) {
            this.datesSeen[journey.calendar.id] = true;
            this.pushDates(journey.calendar.excludes, Day.REMOVED, journey.calendar.id);
            this.pushDates(journey.calendar.includes, Day.ADDED, journey.calendar.id);
        }
    }
    pushDates(dates, type, serviceId) {
        for (const date of dates) {
            this.pushLine(serviceId, date.format(this.dateFormatter), type);
        }
    }
}
exports.CalendarDatesStream = CalendarDatesStream;
var Day;
(function (Day) {
    Day[Day["ADDED"] = 1] = "ADDED";
    Day[Day["REMOVED"] = 2] = "REMOVED";
})(Day || (Day = {}));
