"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CalendarStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
const js_joda_1 = require("js-joda");
/**
 * Extract the calendars from the TransXChange journeys
 */
class CalendarStream extends GTFSFileStream_1.GTFSFileStream {
    constructor() {
        super(...arguments);
        this.datesSeen = {};
        this.dateFormatter = js_joda_1.DateTimeFormatter.ofPattern("yyyyMMdd");
        this.header = "service_id,monday,tuesday,wednesday,thursday,friday,saturday,sunday,start_date,end_date";
    }
    transform(journey) {
        if (!this.datesSeen[journey.calendar.id]) {
            const from = journey.calendar.startDate.format(this.dateFormatter);
            const to = journey.calendar.endDate.format(this.dateFormatter);
            this.pushLine(journey.calendar.id, ...journey.calendar.days, from, to);
            this.datesSeen[journey.calendar.id] = true;
        }
    }
}
exports.CalendarStream = CalendarStream;
