"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GTFSFileStream = void 0;
const stream_1 = require("stream");
/**
 * Transform TransXChange objects into GTFS CSV lines
 */
class GTFSFileStream extends stream_1.Transform {
    constructor() {
        super({ objectMode: true });
        this.headerSent = false;
    }
    /**
     * Emit the header if necessary then pass the chunk to the transform method
     */
    _transform(chunk, encoding, callback) {
        if (!this.headerSent) {
            this.push(this.header + "\n");
            this.headerSent = true;
        }
        this.transform(chunk);
        callback();
    }
    /**
     * Add a new line to whatever is being pushed
     */
    pushLine(...data) {
        const line = data.map(this.quote).join(",");
        return this.push(line + "\n");
    }
    quote(value) {
        return typeof value === "string"
            ? value.includes(",") ? "\"" + value + "\"" : value
            : value + "";
    }
}
exports.GTFSFileStream = GTFSFileStream;
