"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoutesStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
const TransXChange_1 = require("../transxchange/TransXChange");
/**
 * Extract the routes from the TransXChange objects
 */
class RoutesStream extends GTFSFileStream_1.GTFSFileStream {
    constructor() {
        super(...arguments);
        this.header = "route_id,agency_id,route_short_name,route_long_name,route_type,route_text_color,route_color,route_url,route_desc";
        this.routesSeen = {};
        this.routeType = {
            [TransXChange_1.Mode.Air]: 1100,
            [TransXChange_1.Mode.Bus]: 3,
            [TransXChange_1.Mode.Coach]: 3,
            [TransXChange_1.Mode.Ferry]: 4,
            [TransXChange_1.Mode.Train]: 2,
            [TransXChange_1.Mode.Tram]: 0,
            [TransXChange_1.Mode.Underground]: 1
        };
    }
    transform(data) {
        for (const service of Object.values(data.Services)) {
            this.addRoute(service);
        }
    }
    addRoute(service) {
        const routeId = service.ServiceCode;
        if (!this.routesSeen[routeId]) {
            this.routesSeen[routeId] = true;
            const shortDescription = Object.values(service.Lines)[0];
            this.pushLine(routeId, service.RegisteredOperatorRef, shortDescription, service.Description, this.routeType[service.Mode], "", "", "", service.Description);
        }
    }
}
exports.RoutesStream = RoutesStream;
