"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StopsStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
class StopsStream extends GTFSFileStream_1.GTFSFileStream {
    constructor(naptan) {
        super();
        this.naptan = naptan;
        this.header = "stop_id,stop_code,stop_name,stop_desc,stop_lat,stop_lon,zone_id,stop_url,location_type,parent_station,stop_timezone,wheelchair_boarding";
        this.seenStops = {};
    }
    transform(data) {
        for (const stop of data.StopPoints) {
            if (!this.seenStops[stop.StopPointRef]) {
                this.pushLine(...this.getStop(stop));
                this.seenStops[stop.StopPointRef] = true;
            }
        }
    }
    getStop(stop) {
        return this.naptan[stop.StopPointRef] ? this.getNaPTANStop(this.naptan[stop.StopPointRef]) : this.getFeedStop(stop);
    }
    getNaPTANStop([atcoCode, naptanCode, name, street, indicator, locality, parent, lng, lat]) {
        const specificStreet = this.shouldAddStreet(name, street) ? ", " + street : "";
        const specificLocation = indicator !== "" ? " (" + indicator.replace("->", "") + ")" : "";
        const city = parent || locality;
        return [
            atcoCode,
            naptanCode,
            name + specificLocation + specificStreet + ", " + city,
            name,
            lat,
            lng,
            "",
            "",
            "",
            "",
            "",
            0
        ];
    }
    getFeedStop(stop) {
        return [
            stop.StopPointRef,
            "",
            stop.CommonName + ", " + stop.LocalityQualifier,
            "",
            stop.Location.Latitude,
            stop.Location.Longitude,
            "",
            "",
            "",
            "",
            "",
            0
        ];
    }
    /**
     * If the name is not the same as the street name and does not contain any words like Road or Street we can safely
     * add the street name to the name.
     */
    shouldAddStreet(name, street) {
        return street.length > 1
            && name !== street
            && street !== "---"
            && StopsStream.STREET_BLACKLIST.every(i => !name.includes(i));
    }
}
exports.StopsStream = StopsStream;
StopsStream.STREET_BLACKLIST = ["Road", "Street", "Lane", "Avenue"];
