"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransfersStream = void 0;
const GTFSFileStream_1 = require("./GTFSFileStream");
/**
 * Calculate transfers between stops
 */
class TransfersStream extends GTFSFileStream_1.GTFSFileStream {
    constructor(naptan, naptanByLocation) {
        super();
        this.naptan = naptan;
        this.naptanByLocation = naptanByLocation;
        this.stopsSeen = {};
        this.header = "from_stop_id,to_stop_id,transfer_type,min_transfer_time";
    }
    /**
     * Add a transfer from each stop to itself (as interchange time) then find any nearby stops and calculate the time
     * required to walk to them.
     */
    transform(data) {
        for (const stop of data.StopPoints) {
            if (!this.stopsSeen[stop.StopPointRef]) {
                this.pushLine(stop.StopPointRef, stop.StopPointRef, 2, 180);
                if (this.naptan[stop.StopPointRef]) {
                    this.addNearbyStops(stop.StopPointRef);
                }
                this.stopsSeen[stop.StopPointRef] = true;
            }
        }
    }
    /**
     * Search any stops we've seen to see if we can walk there
     */
    addNearbyStops(stop) {
        const aLon = Number(this.naptan[stop][7]);
        const aLat = Number(this.naptan[stop][8]);
        const key = this.naptan[stop][6] || this.naptan[stop][5];
        for (const j of this.naptanByLocation[key]) {
            if (this.naptan[j] && this.stopsSeen[j]) {
                const distance = this.getDistance(aLon, aLat, Number(this.naptan[j][7]), Number(this.naptan[j][8]));
                if (distance < 0.01) {
                    const time = Math.max(60, Math.round((distance / 0.0005) * 120));
                    this.pushLine(stop, j, 2, time);
                    this.pushLine(j, stop, 2, time);
                }
            }
        }
    }
    /**
     * Note this method of calculating distances between stations is flawed and only used as a rough guide.
     */
    getDistance(aLon, aLat, bLon, bLat) {
        return Math.abs(bLat - aLat) + Math.abs(bLon - aLon);
    }
}
exports.TransfersStream = TransfersStream;
