/// <reference types="node" />
import { DaysOfWeek, Holiday, TransXChange } from "./TransXChange";
import { Transform, TransformCallback } from "stream";
import { LocalDate } from "js-joda";
import { ATCOCode } from "../reference/NaPTAN";
/**
 * Transforms TransXChange objects into TransXChangeJourneys that are closer to GTFS calendars, calendar dates, trips
 * and stop times.
 */
export declare class TransXChangeJourneyStream extends Transform {
    private readonly holidays;
    private calendars;
    private serviceId;
    private tripId;
    constructor(holidays: BankHolidays);
    /**
     * Generate a journey
     */
    _transform(schedule: TransXChange, encoding: string, callback: TransformCallback): void;
    private processVehicle;
    private getCalendar;
    private mergeDays;
    private dateRange;
    private getHoliday;
    private getCalendarHash;
    private getStopTimes;
    private getTime;
}
export declare type BankHolidays = Record<Holiday, LocalDate[]>;
export interface TransXChangeJourney {
    calendar: JourneyCalendar;
    trip: {
        id: number;
        shortName: string;
        direction: "inbound" | "outbound";
    };
    route: string;
    stops: StopTime[];
    blockId?: string;
}
export interface JourneyCalendar {
    id: number;
    startDate: LocalDate;
    endDate: LocalDate;
    days: DaysOfWeek;
    includes: LocalDate[];
    excludes: LocalDate[];
}
export interface StopTime {
    stop: ATCOCode;
    arrivalTime: string;
    departureTime: string;
    pickup: boolean;
    dropoff: boolean;
    exactTime: boolean;
}
