"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.daysOfWeekIndex = exports.TransXChangeStream = void 0;
const TransXChange_1 = require("./TransXChange");
const stream_1 = require("stream");
const autobind_decorator_1 = require("autobind-decorator");
const js_joda_1 = require("js-joda");
/**
 * Transforms JSON objects into a TransXChange objects
 */
let TransXChangeStream = class TransXChangeStream extends stream_1.Transform {
    constructor() {
        super({ objectMode: true });
    }
    /**
     * Extract the stops, journeys and operators and emit them as a TransXChange object
     */
    _transform(data, encoding, callback) {
        var _a, _b, _c;
        const tx = data.TransXChange;
        if (!((_a = tx === null || tx === void 0 ? void 0 : tx.VehicleJourneys) === null || _a === void 0 ? void 0 : _a[0].VehicleJourney)) {
            console.warn("Skipping invalid journey");
            return callback();
        }
        let result;
        try {
            const patternIndex = tx.VehicleJourneys[0].VehicleJourney.reduce(this.getJourneyPatternIndex, {});
            const services = tx.Services[0].Service.reduce(this.getServices, {});
            const stops = tx.StopPoints[0].AnnotatedStopPointRef
                ? tx.StopPoints[0].AnnotatedStopPointRef.map(this.getStopFromAnnotatedStopPointRef)
                : tx.StopPoints[0].StopPoint.map(this.getStopFromStopPoint);
            result = {
                StopPoints: stops,
                JourneySections: tx.JourneyPatternSections[0].JourneyPatternSection.reduce(this.getJourneySections, {}),
                Operators: (((_b = tx.Operators) === null || _b === void 0 ? void 0 : _b[0].Operator) || []).concat(((_c = tx.Operators) === null || _c === void 0 ? void 0 : _c[0].LicensedOperator) || []).reduce(this.getOperators, {}),
                Services: services,
                VehicleJourneys: tx.VehicleJourneys[0].VehicleJourney.map((v) => this.getVehicleJourney(v, patternIndex, services))
            };
        }
        catch (err) {
            console.warn(err);
        }
        callback(undefined, result);
    }
    getStopFromAnnotatedStopPointRef(stop) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        return {
            StopPointRef: (_b = (_a = stop === null || stop === void 0 ? void 0 : stop.StopPointRef) === null || _a === void 0 ? void 0 : _a[0]) !== null && _b !== void 0 ? _b : "",
            CommonName: (_d = (_c = stop === null || stop === void 0 ? void 0 : stop.CommonName) === null || _c === void 0 ? void 0 : _c[0]) !== null && _d !== void 0 ? _d : "",
            LocalityName: ((_e = stop === null || stop === void 0 ? void 0 : stop.LocalityName) === null || _e === void 0 ? void 0 : _e[0]) ? stop.LocalityName[0] : "",
            LocalityQualifier: ((_f = stop === null || stop === void 0 ? void 0 : stop.LocalityQualifier) === null || _f === void 0 ? void 0 : _f[0]) ? stop.LocalityQualifier[0] : "",
            Location: {
                Latitude: ((_h = (_g = stop === null || stop === void 0 ? void 0 : stop.Location) === null || _g === void 0 ? void 0 : _g[0]) === null || _h === void 0 ? void 0 : _h.Latitude) ? Number(stop.Location[0].Latitude[0]) : 0.0,
                Longitude: ((_k = (_j = stop === null || stop === void 0 ? void 0 : stop.Location) === null || _j === void 0 ? void 0 : _j[0]) === null || _k === void 0 ? void 0 : _k.Longitude) ? Number(stop.Location[0].Longitude[0]) : 0.0
            }
        };
    }
    getStopFromStopPoint(stop) {
        var _a, _b, _c, _d, _e, _f;
        return {
            StopPointRef: (_b = (_a = stop === null || stop === void 0 ? void 0 : stop.AtcoCode) === null || _a === void 0 ? void 0 : _a[0]) !== null && _b !== void 0 ? _b : "",
            CommonName: (_f = (_e = (_d = (_c = stop === null || stop === void 0 ? void 0 : stop.Descriptor) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.CommonName) === null || _e === void 0 ? void 0 : _e[0]) !== null && _f !== void 0 ? _f : "",
            LocalityName: "",
            LocalityQualifier: "",
            Location: {
                Latitude: 0.0,
                Longitude: 0.0
            }
        };
    }
    getJourneySections(index, section) {
        index[section.$.id] = section.JourneyPatternTimingLink ? section.JourneyPatternTimingLink.map(this.getLink) : [];
        return index;
    }
    getLink(l) {
        var _a, _b, _c, _d, _e, _f;
        return {
            From: this.getJourneyStop((_b = (_a = l === null || l === void 0 ? void 0 : l.From) === null || _a === void 0 ? void 0 : _a[0]) !== null && _b !== void 0 ? _b : ""),
            To: this.getJourneyStop((_d = (_c = l === null || l === void 0 ? void 0 : l.To) === null || _c === void 0 ? void 0 : _c[0]) !== null && _d !== void 0 ? _d : ""),
            RunTime: js_joda_1.Duration.parse((_f = (_e = l === null || l === void 0 ? void 0 : l.RunTime) === null || _e === void 0 ? void 0 : _e[0]) !== null && _f !== void 0 ? _f : "")
        };
    }
    getJourneyStop(stop) {
        var _a, _b, _c, _d, _e, _f;
        return {
            Activity: ((_a = stop === null || stop === void 0 ? void 0 : stop.Activity) === null || _a === void 0 ? void 0 : _a[0]) ? stop.Activity[0] : TransXChange_1.StopActivity.PickUpAndSetDown,
            StopPointRef: (_c = (_b = stop === null || stop === void 0 ? void 0 : stop.StopPointRef) === null || _b === void 0 ? void 0 : _b[0]) !== null && _c !== void 0 ? _c : "",
            TimingStatus: (_e = (_d = stop === null || stop === void 0 ? void 0 : stop.TimingStatus) === null || _d === void 0 ? void 0 : _d[0]) !== null && _e !== void 0 ? _e : "",
            WaitTime: ((_f = stop === null || stop === void 0 ? void 0 : stop.WaitTime) === null || _f === void 0 ? void 0 : _f[0]) && js_joda_1.Duration.parse(stop.WaitTime[0])
        };
    }
    getOperators(index, operator) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        index[operator.$.id] = {
            OperatorCode: ((_a = operator === null || operator === void 0 ? void 0 : operator.OperatorCode) === null || _a === void 0 ? void 0 : _a[0]) ? operator.OperatorCode[0] : (_c = (_b = operator === null || operator === void 0 ? void 0 : operator.NationalOperatorCode) === null || _b === void 0 ? void 0 : _b[0]) !== null && _c !== void 0 ? _c : "",
            OperatorShortName: (_e = (_d = operator === null || operator === void 0 ? void 0 : operator.OperatorShortName) === null || _d === void 0 ? void 0 : _d[0]) !== null && _e !== void 0 ? _e : "",
            OperatorNameOnLicence: ((_f = operator === null || operator === void 0 ? void 0 : operator.OperatorNameOnLicence) === null || _f === void 0 ? void 0 : _f[0]) && ((_j = (_h = (_g = operator.OperatorNameOnLicence[0]) === null || _g === void 0 ? void 0 : _g._) !== null && _h !== void 0 ? _h : operator.OperatorNameOnLicence[0]) !== null && _j !== void 0 ? _j : ""),
        };
        return index;
    }
    getServices(index, service) {
        var _a, _b, _c, _d, _e;
        index[service.ServiceCode[0]] = {
            ServiceCode: service.ServiceCode[0],
            Lines: service.Lines[0].Line.reduce(this.getLines, {}),
            OperatingPeriod: this.getDateRange(service.OperatingPeriod[0]),
            RegisteredOperatorRef: service.RegisteredOperatorRef[0],
            Description: service.Description ? service.Description[0].replace(/[\r\n\t]/g, "") : "",
            Mode: service.Mode ? service.Mode[0] : TransXChange_1.Mode.Bus,
            StandardService: service.StandardService[0].JourneyPattern.reduce(this.getJourneyPattern, {}),
            ServiceOrigin: (_a = service.StandardService[0].Origin) === null || _a === void 0 ? void 0 : _a[0],
            ServiceDestination: (_b = service.StandardService[0].Destination) === null || _b === void 0 ? void 0 : _b[0],
            OperatingProfile: service.OperatingProfile
                ? this.getOperatingProfile(service.OperatingProfile[0])
                : ((_d = (_c = service.StandardService[0].JourneyPattern) === null || _c === void 0 ? void 0 : _c[0].OperatingProfile) === null || _d === void 0 ? void 0 : _d[0])
                    ? this.getOperatingProfile((_e = service.StandardService[0].JourneyPattern) === null || _e === void 0 ? void 0 : _e[0].OperatingProfile[0])
                    : undefined
        };
        return index;
    }
    getJourneyPattern(patterns, pattern) {
        patterns[pattern.$.id] = {
            Direction: pattern.Direction[0],
            Sections: pattern.JourneyPatternSectionRefs
        };
        return patterns;
    }
    getLines(index, line) {
        index[line.$.id] = line.LineName[0];
        return index;
    }
    getDateRange(dates) {
        return {
            StartDate: js_joda_1.LocalDate.parse(dates.StartDate[0]),
            EndDate: dates.EndDate && dates.EndDate[0] ? js_joda_1.LocalDate.parse(dates.EndDate[0]) : js_joda_1.LocalDate.parse("2099-12-31"),
        };
    }
    getVehicleJourney(vehicle, index, services) {
        var _a, _b, _c, _d;
        return {
            LineRef: vehicle.LineRef[0],
            ServiceRef: vehicle.ServiceRef[0],
            VehicleJourneyCode: vehicle.VehicleJourneyCode[0],
            JourneyPatternRef: vehicle.JourneyPatternRef ? vehicle.JourneyPatternRef[0] : index[vehicle.VehicleJourneyRef[0]],
            DepartureTime: js_joda_1.LocalTime.parse(vehicle.DepartureTime[0]),
            OperatingProfile: vehicle.OperatingProfile
                ? this.getOperatingProfile(vehicle.OperatingProfile[0])
                : services[vehicle.ServiceRef[0]].OperatingProfile,
            OperationalBlockNumber: (_d = (_c = (_b = (_a = vehicle.Operational) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.Block) === null || _c === void 0 ? void 0 : _c[0].BlockNumber) === null || _d === void 0 ? void 0 : _d[0]
        };
    }
    getOperatingProfile(profile) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        const result = {
            BankHolidayOperation: {
                DaysOfOperation: [],
                DaysOfNonOperation: []
            },
            SpecialDaysOperation: {
                DaysOfOperation: [],
                DaysOfNonOperation: []
            },
            RegularDayType: profile.RegularDayType[0].DaysOfWeek
                ? this.getDaysOfWeek(profile.RegularDayType[0].DaysOfWeek[0])
                : "HolidaysOnly"
        };
        if ((_b = (_a = profile.BankHolidayOperation) === null || _a === void 0 ? void 0 : _a[0].DaysOfOperation) === null || _b === void 0 ? void 0 : _b[0]) {
            result.BankHolidayOperation.DaysOfOperation = this.getHolidays(profile.BankHolidayOperation[0].DaysOfOperation[0]);
            if (profile.BankHolidayOperation[0].DaysOfOperation[0].OtherPublicHoliday) {
                const operationDates = profile.BankHolidayOperation[0].DaysOfOperation[0].OtherPublicHoliday
                    .map((d) => this.getHolidayDate(d.Date[0]));
                result.SpecialDaysOperation.DaysOfOperation.push(...operationDates);
            }
        }
        if ((_d = (_c = profile.BankHolidayOperation) === null || _c === void 0 ? void 0 : _c[0].DaysOfNonOperation) === null || _d === void 0 ? void 0 : _d[0]) {
            result.BankHolidayOperation.DaysOfNonOperation = this.getHolidays(profile.BankHolidayOperation[0].DaysOfNonOperation[0]);
            if (profile.BankHolidayOperation[0].DaysOfNonOperation[0].OtherPublicHoliday) {
                const nonOperationDates = profile.BankHolidayOperation[0].DaysOfNonOperation[0].OtherPublicHoliday
                    .map((d) => this.getHolidayDate(d.Date[0]));
                result.SpecialDaysOperation.DaysOfNonOperation.push(...nonOperationDates);
            }
        }
        if ((_f = (_e = profile.SpecialDaysOperation) === null || _e === void 0 ? void 0 : _e[0].DaysOfOperation) === null || _f === void 0 ? void 0 : _f[0]) {
            result.SpecialDaysOperation.DaysOfOperation = profile.SpecialDaysOperation[0].DaysOfOperation[0].DateRange.map(this.getDateRange);
        }
        if ((_h = (_g = profile.SpecialDaysOperation) === null || _g === void 0 ? void 0 : _g[0].DaysOfNonOperation) === null || _h === void 0 ? void 0 : _h[0]) {
            result.SpecialDaysOperation.DaysOfNonOperation = profile.SpecialDaysOperation[0].DaysOfNonOperation[0].DateRange.map(this.getDateRange);
        }
        return result;
    }
    getHolidays(days) {
        return Object
            .keys(days)
            .filter(k => k !== "OtherPublicHoliday");
    }
    getHolidayDate(date) {
        const StartDate = js_joda_1.LocalDate.parse(date);
        const EndDate = StartDate;
        return { StartDate, EndDate };
    }
    getDaysOfWeek(days) {
        return Object.keys(days).length === 0
            ? [[0, 0, 0, 0, 0, 0, 0]]
            : Object.keys(days).map(d => exports.daysOfWeekIndex[d] || [0, 0, 0, 0, 0, 0, 0]);
    }
    getJourneyPatternIndex(index, vehicle) {
        if (vehicle.JourneyPatternRef) {
            index[vehicle.VehicleJourneyCode[0]] = vehicle.JourneyPatternRef[0];
        }
        return index;
    }
};
TransXChangeStream = __decorate([
    autobind_decorator_1.default
], TransXChangeStream);
exports.TransXChangeStream = TransXChangeStream;
/**
 * TransXChange's comical idea of how to represent days of operation
 */
exports.daysOfWeekIndex = {
    "MondayToFriday": [1, 1, 1, 1, 1, 0, 0],
    "MondayToSaturday": [1, 1, 1, 1, 1, 1, 0],
    "MondayToSunday": [1, 1, 1, 1, 1, 1, 1],
    "NotSaturday": [1, 1, 1, 1, 1, 0, 1],
    "Weekend": [0, 0, 0, 0, 0, 1, 1],
    "Monday": [1, 0, 0, 0, 0, 0, 0],
    "Tuesday": [0, 1, 0, 0, 0, 0, 0],
    "Wednesday": [0, 0, 1, 0, 0, 0, 0],
    "Thursday": [0, 0, 0, 1, 0, 0, 0],
    "Friday": [0, 0, 0, 0, 1, 0, 0],
    "Saturday": [0, 0, 0, 0, 0, 1, 0],
    "Sunday": [0, 0, 0, 0, 0, 0, 1],
};
