"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const util_1 = require("../util");
const js_joda_1 = require("js-joda");
const CalendarStream_1 = require("../../src/gtfs/CalendarStream");
const CalendarDatesStream_1 = require("../../src/gtfs/CalendarDatesStream");
// tslint:disable
describe("CalendarDatesStream", () => {
    it("emits calendar dates", async () => {
        const stream = new CalendarDatesStream_1.CalendarDatesStream();
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [js_joda_1.LocalDate.parse("2018-06-01")],
                excludes: [js_joda_1.LocalDate.parse("2018-12-25")]
            }
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            const exclude = (0, util_1.splitCSV)(rows[1]);
            const include = (0, util_1.splitCSV)(rows[2]);
            chai.expect(exclude[0]).to.equal("1");
            chai.expect(exclude[1]).to.equal("20181225");
            chai.expect(exclude[2]).to.equal("2");
            chai.expect(include[0]).to.equal("1");
            chai.expect(include[1]).to.equal("20180601");
            chai.expect(include[2]).to.equal("1");
        });
    });
    it("doesn't emit the same calendar twice", async () => {
        const stream = new CalendarStream_1.CalendarStream();
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [],
                excludes: []
            }
        });
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [],
                excludes: []
            }
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            chai.expect(rows.length).to.equal(2);
        });
    });
});
