"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const util_1 = require("../util");
const js_joda_1 = require("js-joda");
const CalendarStream_1 = require("../../src/gtfs/CalendarStream");
// tslint:disable
describe("CalendarStream", () => {
    it("emits calendars", async () => {
        const stream = new CalendarStream_1.CalendarStream();
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [],
                excludes: []
            }
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            const [service_id, monday, tuesday, wednesday, thursday, friday, saturday, sunday, start_date, end_date] = (0, util_1.splitCSV)(rows[1]);
            chai.expect(service_id).to.equal("1");
            chai.expect(monday).to.equal("1");
            chai.expect(tuesday).to.equal("1");
            chai.expect(wednesday).to.equal("1");
            chai.expect(thursday).to.equal("1");
            chai.expect(friday).to.equal("1");
            chai.expect(saturday).to.equal("1");
            chai.expect(sunday).to.equal("1");
            chai.expect(start_date).to.equal("20180624");
            chai.expect(end_date).to.equal("20991231");
        });
    });
    it("doesn't emit the same calendar twice", async () => {
        const stream = new CalendarStream_1.CalendarStream();
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [],
                excludes: []
            }
        });
        stream.write({
            calendar: {
                id: 1,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [],
                excludes: []
            }
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            chai.expect(rows.length).to.equal(2);
        });
    });
});
