"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const util_1 = require("../util");
const js_joda_1 = require("js-joda");
const TripsStream_1 = require("../../src/gtfs/TripsStream");
// tslint:disable
describe("TripsStream", () => {
    it("emits calendar trips", async () => {
        const stream = new TripsStream_1.TripsStream();
        stream.write({
            calendar: {
                id: 3,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [js_joda_1.LocalDate.parse("2018-06-01")],
                excludes: [js_joda_1.LocalDate.parse("2018-12-25")]
            },
            trip: {
                id: 2,
                shortName: "Victoria, London",
                direction: "inbound"
            },
            route: 1,
            blockId: "abc134"
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            const [route_id, service_id, trip_id, trip_headsign, trip_short_name, direction_id, wheelchair_accessible, bikes_allowed, block_id] = (0, util_1.splitCSV)(rows[1]);
            chai.expect(route_id).to.equal("1");
            chai.expect(service_id).to.equal("3");
            chai.expect(trip_id).to.equal("2");
            chai.expect(trip_headsign).to.equal("");
            chai.expect(trip_short_name).to.equal('Victoria, London');
            chai.expect(direction_id).to.equal("1");
            chai.expect(wheelchair_accessible).to.equal("0");
            chai.expect(bikes_allowed).to.equal("0");
            chai.expect(block_id).to.equal("abc134");
        });
    });
    it("emits empty for undefined block_id", async () => {
        const stream = new TripsStream_1.TripsStream();
        stream.write({
            calendar: {
                id: 3,
                startDate: js_joda_1.LocalDate.parse("2018-06-24"),
                endDate: js_joda_1.LocalDate.parse("2099-12-31"),
                days: [1, 1, 1, 1, 1, 1, 1],
                includes: [js_joda_1.LocalDate.parse("2018-06-01")],
                excludes: [js_joda_1.LocalDate.parse("2018-12-25")]
            },
            trip: {
                id: 2,
                shortName: "Victoria, London",
                direction: "inbound"
            },
            route: 1,
        });
        stream.end();
        return (0, util_1.awaitStream)(stream, (rows) => {
            const [, , , , , , , , block_id] = (0, util_1.splitCSV)(rows[1]);
            chai.expect(block_id).to.equal(undefined);
        });
    });
});
