"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const util_1 = require("../util");
const TransXChangeStream_1 = require("../../src/transxchange/TransXChangeStream");
const js_joda_1 = require("js-joda");
describe("TransXChangeStream", () => {
    it("extracts the stops from the raw JSON object", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.StopPoints).to.deep.equal([
                {
                    "CommonName": "Cabot Circus",
                    "LocalityName": "Cabot Circus",
                    "LocalityQualifier": "Bristol",
                    "StopPointRef": "010000036",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "UWE Entrance North",
                    "LocalityName": "Abbey Wood",
                    "LocalityQualifier": "Bristol",
                    "StopPointRef": "0170SGA56570",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Argos",
                    "LocalityName": "Falmouth",
                    "LocalityQualifier": "Falmouth",
                    "StopPointRef": "0800COA15248",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Bus Station",
                    "LocalityName": "Newquay",
                    "LocalityQualifier": "Newquay",
                    "StopPointRef": "0800COA15390",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Penryn Campus Falmouth Univ",
                    "LocalityName": "Tremough",
                    "LocalityQualifier": "Tremough",
                    "StopPointRef": "0800COA15596",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Cornwall Services",
                    "LocalityName": "Victoria",
                    "LocalityQualifier": "Victoria",
                    "StopPointRef": "0800COA15732",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Railway Station",
                    "LocalityName": "Redruth",
                    "LocalityQualifier": "Redruth",
                    "StopPointRef": "0800COC30451",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Railway Station",
                    "LocalityName": "Redruth",
                    "LocalityQualifier": "Redruth",
                    "StopPointRef": "0800COD41085",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Sidwell Street",
                    "LocalityName": "Exeter City Centre",
                    "LocalityQualifier": "Exeter",
                    "StopPointRef": "1100DEC10183",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Penn Inn",
                    "LocalityName": "Milber",
                    "LocalityQualifier": "Newton Abbot",
                    "StopPointRef": "1100DEM55092",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Penn Inn",
                    "LocalityName": "Milber",
                    "LocalityQualifier": "Newton Abbot",
                    "StopPointRef": "1100DEM55093",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Plymouth Coach Station",
                    "LocalityName": "Plymouth City Centre",
                    "LocalityQualifier": "Plymouth",
                    "StopPointRef": "118000037",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "University",
                    "LocalityName": "Plymouth",
                    "LocalityQualifier": "Plymouth",
                    "StopPointRef": "1180033077",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Coach Station",
                    "LocalityName": "Torquay",
                    "LocalityQualifier": "Torbay",
                    "StopPointRef": "1190TOA10663",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Bus Station",
                    "LocalityName": "Paignton",
                    "LocalityQualifier": "Torbay",
                    "StopPointRef": "1190TOZ00813",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Victoria Coach Station",
                    "LocalityName": "Belgravia",
                    "LocalityQualifier": "Victoria",
                    "StopPointRef": "490014051VC",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                },
                {
                    "CommonName": "Victoria Coach Station Arrivals",
                    "LocalityName": "Victoria",
                    "LocalityQualifier": "London",
                    "StopPointRef": "490016736W",
                    "Location": {
                        "Latitude": 0.0,
                        "Longitude": 0.0
                    }
                }
            ]);
        });
    });
    it("extracts the stops from StopPoints", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example3);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.StopPoints).to.deep.equal([
                {
                    "CommonName": "Queen Square Bus Station",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42023I"
                },
                {
                    "CommonName": "Metropolitan Cathedral",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42053E"
                },
                {
                    "CommonName": "Adelphi Hotel",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42051A"
                },
                {
                    "CommonName": "World Museum",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42063A"
                },
                {
                    "CommonName": "Pilgrim Street",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41157B"
                },
                {
                    "CommonName": "Salthouse Quay",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41186A"
                },
                {
                    "CommonName": "Brunswick Street",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42088A"
                },
                {
                    "CommonName": "Exhibition Centre Liverpool",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41228B"
                },
                {
                    "CommonName": "Temple Lane",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42079B"
                },
                {
                    "CommonName": "Arrad Street",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41200B"
                },
                {
                    "CommonName": "Bold Place",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41050A"
                },
                {
                    "CommonName": "North John Street",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S42022B"
                },
                {
                    "CommonName": "Upper Duke Street",
                    "LocalityName": "",
                    "LocalityQualifier": "",
                    "Location": {
                        "Latitude": 0,
                        "Longitude": 0
                    },
                    "StopPointRef": "2800S41049B"
                },
            ]);
        });
    });
    it("extracts the operators from the raw JSON object", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.Operators).to.deep.equal({
                "OId_MEGA": {
                    "OperatorCode": "MEGA",
                    "OperatorNameOnLicence": "Stagecoach Megabus",
                    "OperatorShortName": "Megabus"
                }
            });
        });
    });
    it("extracts the journey sections from the raw JSON object", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.JourneySections["JPSection-1"][0]).to.deep.equal({
                "From": {
                    "Activity": "pickUp",
                    "StopPointRef": "490014051VC",
                    "WaitTime": undefined,
                    "TimingStatus": "PTP"
                },
                "RunTime": js_joda_1.Duration.parse("PT130M"),
                "To": {
                    "Activity": "pickUpAndSetDown",
                    "StopPointRef": "0170SGA56570",
                    "WaitTime": undefined,
                    "TimingStatus": "PTP"
                }
            });
            chai.expect(row.JourneySections["JPSection-1"][4]).to.deep.equal({
                "From": {
                    "Activity": "pickUpAndSetDown",
                    "StopPointRef": "1180033077",
                    "WaitTime": undefined,
                    "TimingStatus": "PTP"
                },
                "RunTime": js_joda_1.Duration.parse("PT10M"),
                "To": {
                    "Activity": "pickUpAndSetDown",
                    "StopPointRef": "118000037",
                    "WaitTime": js_joda_1.Duration.parse("PT5M"),
                    "TimingStatus": "PTP"
                }
            });
        });
    });
    it("extracts the services", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.Services["M6_MEGA"]).to.deep.equal({
                "Description": "Falmouth - Victoria,London",
                "Lines": {
                    "l_M6_MEGA": "M6"
                },
                "Mode": "coach",
                "OperatingPeriod": {
                    "EndDate": js_joda_1.LocalDate.parse("2099-12-31"),
                    "StartDate": js_joda_1.LocalDate.parse("2018-06-24")
                },
                "OperatingProfile": undefined,
                "RegisteredOperatorRef": "OId_MEGA",
                "ServiceCode": "M6_MEGA",
                "ServiceOrigin": "Falmouth",
                "ServiceDestination": "Victoria, London",
                "StandardService": {
                    "JP366": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-45",
                            "JPSection-66",
                            "JPSection-17"
                        ]
                    },
                    "JP367": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-46",
                            "JPSection-67",
                            "JPSection-18"
                        ]
                    },
                    "JP368": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-15",
                            "JPSection-68",
                            "JPSection-13"
                        ]
                    },
                    "JP369": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-16",
                            "JPSection-69",
                            "JPSection-14"
                        ]
                    },
                    "JP370": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-70",
                            "JPSection-23",
                            "JPSection-71",
                            "JPSection-3"
                        ]
                    },
                    "JP371": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-72",
                            "JPSection-24",
                            "JPSection-73",
                            "JPSection-4"
                        ]
                    },
                    "JP372": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-49",
                            "JPSection-74",
                            "JPSection-47"
                        ]
                    },
                    "JP373": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-19"
                        ]
                    },
                    "JP375": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-75"
                        ]
                    },
                    "JP376": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-20"
                        ]
                    },
                    "JP378": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-50",
                            "JPSection-76",
                            "JPSection-48"
                        ]
                    },
                    "JP379": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-1"
                        ]
                    },
                    "JP380": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-5"
                        ]
                    },
                    "JP382": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-2"
                        ]
                    },
                    "JP383": {
                        "Direction": "outbound",
                        "Sections": [
                            "JPSection-6"
                        ]
                    },
                    "JP384": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-51",
                            "JPSection-77",
                            "JPSection-21"
                        ]
                    },
                    "JP385": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-52",
                            "JPSection-78",
                            "JPSection-9"
                        ]
                    },
                    "JP386": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-25",
                            "JPSection-54",
                            "JPSection-79"
                        ]
                    },
                    "JP387": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-7",
                            "JPSection-56"
                        ]
                    },
                    "JP388": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-26",
                            "JPSection-80"
                        ]
                    },
                    "JP389": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-53",
                            "JPSection-81",
                            "JPSection-36"
                        ]
                    },
                    "JP390": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-27",
                            "JPSection-57"
                        ]
                    },
                    "JP391": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-28",
                            "JPSection-39"
                        ]
                    },
                    "JP392": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-8",
                            "JPSection-82"
                        ]
                    },
                    "JP393": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-43",
                            "JPSection-41",
                            "JPSection-83",
                            "JPSection-34",
                            "JPSection-84"
                        ]
                    },
                    "JP394": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-44",
                            "JPSection-85",
                            "JPSection-60",
                            "JPSection-35",
                            "JPSection-58"
                        ]
                    },
                    "JP395": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-11",
                            "JPSection-61",
                            "JPSection-33",
                            "JPSection-59"
                        ]
                    },
                    "JP396": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-12",
                            "JPSection-86",
                            "JPSection-40"
                        ]
                    },
                    "JP397": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-29",
                            "JPSection-87"
                        ]
                    },
                    "JP398": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-30",
                            "JPSection-55",
                            "JPSection-37"
                        ]
                    },
                    "JP399": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-31",
                            "JPSection-88",
                            "JPSection-38"
                        ]
                    },
                    "JP400": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-32",
                            "JPSection-89"
                        ]
                    },
                    "JP402": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-90",
                            "JPSection-64",
                            "JPSection-42",
                            "JPSection-91",
                            "JPSection-62",
                            "JPSection-92",
                            "JPSection-22"
                        ]
                    },
                    "JP404": {
                        "Direction": "inbound",
                        "Sections": [
                            "JPSection-93",
                            "JPSection-65",
                            "JPSection-94",
                            "JPSection-63",
                            "JPSection-95",
                            "JPSection-10"
                        ]
                    }
                }
            });
        });
    });
    it("extracts the vehicle journeys", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.VehicleJourneys[5]).to.deep.equal({
                "DepartureTime": js_joda_1.LocalTime.parse("13:00"),
                "JourneyPatternRef": "JP371",
                "VehicleJourneyCode": "0616",
                "LineRef": "l_M6_MEGA",
                "OperatingProfile": {
                    "BankHolidayOperation": {
                        "DaysOfNonOperation": [],
                        "DaysOfOperation": []
                    },
                    "RegularDayType": [[0, 0, 0, 0, 0, 1, 0]],
                    "SpecialDaysOperation": {
                        "DaysOfNonOperation": [],
                        "DaysOfOperation": []
                    },
                },
                "ServiceRef": "M6_MEGA",
                "OperationalBlockNumber": undefined
            });
        });
    });
    it("copies vehicle journey references", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.VehicleJourneys[18]).to.deep.equal({
                "DepartureTime": js_joda_1.LocalTime.parse("01:00"),
                "JourneyPatternRef": "JP384",
                "VehicleJourneyCode": "0601",
                "LineRef": "l_M6_MEGA",
                "OperatingProfile": {
                    "BankHolidayOperation": {
                        "DaysOfNonOperation": [],
                        "DaysOfOperation": []
                    },
                    "RegularDayType": [[1, 1, 1, 1, 1, 1, 1]],
                    "SpecialDaysOperation": {
                        "DaysOfNonOperation": [{
                                StartDate: js_joda_1.LocalDate.parse("2018-08-08"),
                                EndDate: js_joda_1.LocalDate.parse("2099-12-31")
                            }],
                        "DaysOfOperation": []
                    }
                },
                "ServiceRef": "M6_MEGA",
                "OperationalBlockNumber": undefined
            });
        });
    });
    it("parses self closing dates", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example2);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.VehicleJourneys[0]).to.deep.equal({
                "DepartureTime": js_joda_1.LocalTime.parse("10:00"),
                "JourneyPatternRef": undefined,
                "VehicleJourneyCode": "J78",
                "LineRef": "l_101_2357",
                "OperatingProfile": {
                    "BankHolidayOperation": {
                        "DaysOfNonOperation": [],
                        "DaysOfOperation": ["AllBankHolidays"]
                    },
                    "RegularDayType": [[0, 0, 0, 0, 0, 0, 0]],
                    "SpecialDaysOperation": {
                        "DaysOfNonOperation": [{
                                StartDate: js_joda_1.LocalDate.parse("2018-10-29"),
                                EndDate: js_joda_1.LocalDate.parse("2018-12-31")
                            }],
                        "DaysOfOperation": []
                    }
                },
                "ServiceRef": "NW_06_2357_101_1",
                "OperationalBlockNumber": undefined
            });
        });
    });
    it("parses blockId if one exists", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example4);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.VehicleJourneys[0]).to.deep.equal({
                "DepartureTime": js_joda_1.LocalTime.parse("05:39"),
                "JourneyPatternRef": "JP1",
                "VehicleJourneyCode": "VJ1",
                "LineRef": "SL1",
                "OperatingProfile": {
                    "BankHolidayOperation": {
                        "DaysOfNonOperation": ["GoodFriday", "LateSummerBankHolidayNotScotland", "MayDay", "EasterMonday", "SpringBank"],
                        "DaysOfOperation": []
                    },
                    "RegularDayType": [[1, 1, 1, 1, 1, 0, 0]],
                    "SpecialDaysOperation": {
                        "DaysOfNonOperation": [],
                        "DaysOfOperation": []
                    }
                },
                "ServiceRef": "FMAN006A",
                "OperationalBlockNumber": "351"
            });
        });
    });
    it("parses the OperatingProfile", async () => {
        const stream = new TransXChangeStream_1.TransXChangeStream();
        stream.write(example5);
        stream.end();
        return (0, util_1.awaitStream)(stream, ([row]) => {
            chai.expect(row.VehicleJourneys[0].OperatingProfile).to.deep.equal({
                "BankHolidayOperation": {
                    "DaysOfNonOperation": ["Christmas", "NewYearsDay", "ChristmasDayHoliday", "BoxingDayHoliday", "NewYearsDayHoliday"],
                    "DaysOfOperation": ["GoodFriday", "LateSummerBankHolidayNotScotland", "MayDay", "EasterMonday", "SpringBank"]
                },
                "RegularDayType": [[0, 0, 0, 0, 0, 0, 1]],
                "SpecialDaysOperation": {
                    "DaysOfNonOperation": [],
                    "DaysOfOperation": [{ "StartDate": js_joda_1.LocalDate.parse("2022-06-03"), EndDate: js_joda_1.LocalDate.parse("2022-06-03") }]
                }
            });
        });
    });
});
// tslint:disable
const example = { "TransXChange": { "$": { "xmlns:xsd": "http://www.w3.org/2001/XMLSchema", "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance", "xsi:schemaLocation": "http://www.transxchange.org.uk/ http://www.transxchange.org.uk/schema/2.1/TransXChange_general.xsd", "CreationDateTime": "2018-08-03T10:59:23.2874143+01:00", "ModificationDateTime": "2018-08-03T10:59:23.2874143+01:00", "Modification": "new", "RevisionNumber": "1", "FileName": "TXC.xml", "SchemaVersion": "2.1", "xmlns": "http://www.transxchange.org.uk/" }, "StopPoints": [{ "AnnotatedStopPointRef": [{ "StopPointRef": ["010000036"], "CommonName": ["Cabot Circus"], "LocalityName": ["Cabot Circus"], "LocalityQualifier": ["Bristol"] }, { "StopPointRef": ["0170SGA56570"], "CommonName": ["UWE Entrance North"], "LocalityName": ["Abbey Wood"], "LocalityQualifier": ["Bristol"] }, { "StopPointRef": ["0800COA15248"], "CommonName": ["Argos"], "LocalityName": ["Falmouth"], "LocalityQualifier": ["Falmouth"] }, { "StopPointRef": ["0800COA15390"], "CommonName": ["Bus Station"], "LocalityName": ["Newquay"], "LocalityQualifier": ["Newquay"] }, { "StopPointRef": ["0800COA15596"], "CommonName": ["Penryn Campus Falmouth Univ"], "LocalityName": ["Tremough"], "LocalityQualifier": ["Tremough"] }, { "StopPointRef": ["0800COA15732"], "CommonName": ["Cornwall Services"], "LocalityName": ["Victoria"], "LocalityQualifier": ["Victoria"] }, { "StopPointRef": ["0800COC30451"], "CommonName": ["Railway Station"], "LocalityName": ["Redruth"], "LocalityQualifier": ["Redruth"] }, { "StopPointRef": ["0800COD41085"], "CommonName": ["Railway Station"], "LocalityName": ["Redruth"], "LocalityQualifier": ["Redruth"] }, { "StopPointRef": ["1100DEC10183"], "CommonName": ["Sidwell Street"], "LocalityName": ["Exeter City Centre"], "LocalityQualifier": ["Exeter"] }, { "StopPointRef": ["1100DEM55092"], "CommonName": ["Penn Inn"], "LocalityName": ["Milber"], "LocalityQualifier": ["Newton Abbot"] }, { "StopPointRef": ["1100DEM55093"], "CommonName": ["Penn Inn"], "LocalityName": ["Milber"], "LocalityQualifier": ["Newton Abbot"] }, { "StopPointRef": ["118000037"], "CommonName": ["Plymouth Coach Station"], "LocalityName": ["Plymouth City Centre"], "LocalityQualifier": ["Plymouth"] }, { "StopPointRef": ["1180033077"], "CommonName": ["University"], "LocalityName": ["Plymouth"], "LocalityQualifier": ["Plymouth"] }, { "StopPointRef": ["1190TOA10663"], "CommonName": ["Coach Station"], "LocalityName": ["Torquay"], "LocalityQualifier": ["Torbay"] }, { "StopPointRef": ["1190TOZ00813"], "CommonName": ["Bus Station"], "LocalityName": ["Paignton"], "LocalityQualifier": ["Torbay"] }, { "StopPointRef": ["490014051VC"], "CommonName": ["Victoria Coach Station"], "LocalityName": ["Belgravia"], "LocalityQualifier": ["Victoria"] }, { "StopPointRef": ["490016736W"], "CommonName": ["Victoria Coach Station Arrivals"], "LocalityName": ["Victoria"], "LocalityQualifier": ["London"] }] }], "JourneyPatternSections": [{ "JourneyPatternSection": [{ "$": { "id": "JPSection-1" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-1-SEC12-POS30" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-1-SEC2-POS6" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-1-SEC12-POS31" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }, { "$": { "id": "JPSection-1-SEC12-POS32" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-1-SEC3-POS10" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-1-SEC4-POS16" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-1-SEC12-POS33" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }, { "$": { "id": "JPSection-1-SEC12-POS34" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT50M"] }, { "$": { "id": "JPSection-1-SEC12-POS35" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-1-SEC12-POS36" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-2" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-2-SEC12-POS30" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-2-SEC2-POS6" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-2-SEC12-POS31" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }, { "$": { "id": "JPSection-2-SEC12-POS32" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-2-SEC3-POS10" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-2-SEC4-POS16" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-2-SEC12-POS33" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }, { "$": { "id": "JPSection-2-SEC12-POS34" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT50M"] }, { "$": { "id": "JPSection-2-SEC12-POS35" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-2-SEC12-POS36" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-3" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-3-SEC5-POS18" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT120M"] }, { "$": { "id": "JPSection-3-SEC5-POS19" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-3-SEC3-POS13" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-3-SEC3-POS14" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-3-SEC3-POS15" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-4" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-4-SEC5-POS18" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT120M"] }, { "$": { "id": "JPSection-4-SEC5-POS19" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-4-SEC3-POS13" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-4-SEC3-POS14" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-4-SEC3-POS15" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-5" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-5-SEC12-POS30" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-5-SEC2-POS6" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-5-SEC12-POS31" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }, { "$": { "id": "JPSection-5-SEC12-POS32" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-5-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-6" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-6-SEC12-POS30" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-6-SEC2-POS6" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-6-SEC12-POS31" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }, { "$": { "id": "JPSection-6-SEC12-POS32" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }, { "$": { "id": "JPSection-6-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-7" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-7-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC17-POS42" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }, { "$": { "id": "JPSection-7-SEC19-POS49" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-7-SEC19-POS50" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-7-SEC19-POS51" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT45M"] }] }, { "$": { "id": "JPSection-8" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-8-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC17-POS42" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }, { "$": { "id": "JPSection-8-SEC19-POS49" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-8-SEC19-POS50" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-8-SEC19-POS51" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT45M"] }] }, { "$": { "id": "JPSection-9" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-9-SEC17-POS43" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-9-SEC17-POS44" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUp"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-9-SEC17-POS45" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUp"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT45M"] }, { "$": { "id": "JPSection-9-SEC17-POS46" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }, { "$": { "id": "JPSection-9-SEC17-POS47" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-10" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-10-SEC17-POS43" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-10-SEC17-POS44" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUp"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-10-SEC17-POS45" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUp"], "StopPointRef": ["1100DEM55093"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT45M"] }, { "$": { "id": "JPSection-10-SEC17-POS46" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }, { "$": { "id": "JPSection-10-SEC17-POS47" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-11" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-11-SEC25-POS59" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-11-SEC25-POS60" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-11-SEC27-POS70" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT35M"] }, { "$": { "id": "JPSection-11-SEC26-POS66" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-11-SEC27-POS71" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT105M"] }] }, { "$": { "id": "JPSection-12" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-12-SEC25-POS59" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-12-SEC25-POS60" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-12-SEC27-POS70" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT35M"] }, { "$": { "id": "JPSection-12-SEC26-POS66" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-12-SEC27-POS71" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT105M"] }] }, { "$": { "id": "JPSection-13" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-13-SEC3-POS12" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT35M"] }, { "$": { "id": "JPSection-13-SEC3-POS13" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-13-SEC3-POS14" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-13-SEC3-POS15" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-14" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-14-SEC3-POS12" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT35M"] }, { "$": { "id": "JPSection-14-SEC3-POS13" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-14-SEC3-POS14" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COD41085"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-14-SEC3-POS15" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-15" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-15-SEC3-POS7" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }, { "$": { "id": "JPSection-15-SEC3-POS8" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-15-SEC3-POS9" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT85M"] }, { "$": { "id": "JPSection-15-SEC3-POS10" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-16" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-16-SEC3-POS7" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }, { "$": { "id": "JPSection-16-SEC3-POS8" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-16-SEC3-POS9" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT85M"] }, { "$": { "id": "JPSection-16-SEC3-POS10" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-17" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-17-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT125M"] }, { "$": { "id": "JPSection-17-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-17-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-18" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-18-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT125M"] }, { "$": { "id": "JPSection-18-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-18-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-19" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-19-SEC7-POS21" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT270M"] }, { "$": { "id": "JPSection-19-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-19-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-20" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-20-SEC7-POS21" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT270M"] }, { "$": { "id": "JPSection-20-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-20-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-21" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-21-SEC16-POS39" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }, { "$": { "id": "JPSection-21-SEC16-POS40" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-21-SEC16-POS41" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-22" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-22-SEC16-POS39" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }, { "$": { "id": "JPSection-22-SEC16-POS40" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-22-SEC16-POS41" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-23" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-23-SEC3-POS8" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-23-SEC3-POS9" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT85M"] }] }, { "$": { "id": "JPSection-24" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-24-SEC3-POS8" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT130M"] }, { "$": { "id": "JPSection-24-SEC3-POS9" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT85M"] }] }, { "$": { "id": "JPSection-25" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-25-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-25-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }] }, { "$": { "id": "JPSection-26" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-26-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-26-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }] }, { "$": { "id": "JPSection-27" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-27-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-27-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }] }, { "$": { "id": "JPSection-28" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-28-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-28-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }] }, { "$": { "id": "JPSection-29" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-29-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-29-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }] }, { "$": { "id": "JPSection-30" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-30-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-30-SEC30-POS75" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT75M"] }] }, { "$": { "id": "JPSection-31" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-31-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-31-SEC30-POS75" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT75M"] }] }, { "$": { "id": "JPSection-32" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-32-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-32-SEC30-POS75" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT75M"] }] }, { "$": { "id": "JPSection-33" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-33-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-33-SEC23-POS57" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }] }, { "$": { "id": "JPSection-34" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-34-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-34-SEC16-POS39" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }] }, { "$": { "id": "JPSection-35" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-35-SEC18-POS48" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-35-SEC16-POS39" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }] }, { "$": { "id": "JPSection-36" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-36-SEC16-POS40" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-36-SEC21-POS56" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT150M"] }] }, { "$": { "id": "JPSection-37" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-37-SEC16-POS40" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-37-SEC21-POS56" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT150M"] }] }, { "$": { "id": "JPSection-38" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-38-SEC16-POS40" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-38-SEC21-POS56" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT150M"] }] }, { "$": { "id": "JPSection-39" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-39-SEC23-POS57" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }, { "$": { "id": "JPSection-39-SEC17-POS47" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-40" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-40-SEC23-POS57" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }, { "$": { "id": "JPSection-40-SEC17-POS47" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-41" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-41-SEC25-POS61" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-41-SEC25-POS62" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-42" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-42-SEC25-POS61" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-42-SEC25-POS62" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-43" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-43-SEC25-POS59" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-43-SEC25-POS60" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-44" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-44-SEC25-POS59" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }, { "$": { "id": "JPSection-44-SEC25-POS60" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-45" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-45-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT150M"] }] }, { "$": { "id": "JPSection-46" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-46-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "RunTime": ["PT150M"] }] }, { "$": { "id": "JPSection-47" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-47-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-48" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-48-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-49" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-49-SEC7-POS21" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT270M"] }] }, { "$": { "id": "JPSection-50" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-50-SEC7-POS21" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT270M"] }] }, { "$": { "id": "JPSection-51" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-51-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-52" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-52-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-53" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-53-SEC16-POS37" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-54" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-54-SEC17-POS46" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }] }, { "$": { "id": "JPSection-55" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-55-SEC17-POS46" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }] }, { "$": { "id": "JPSection-56" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-56-SEC19-POS52" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT265M"] }] }, { "$": { "id": "JPSection-57" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-57-SEC19-POS52" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT265M"] }] }, { "$": { "id": "JPSection-58" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-58-SEC26-POS69" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT180M"] }] }, { "$": { "id": "JPSection-59" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-59-SEC26-POS69" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT180M"] }] }, { "$": { "id": "JPSection-60" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-60-SEC26-POS68" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-61" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-61-SEC26-POS68" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-62" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-62-SEC26-POS68" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-63" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-63-SEC26-POS68" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }] }, { "$": { "id": "JPSection-64" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-64-SEC33-POS78" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-65" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-65-SEC33-POS78" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }] }, { "$": { "id": "JPSection-66" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-66-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT15M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }] }, { "$": { "id": "JPSection-67" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-67-SEC2-POS6" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0170SGA56570"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }] }, { "$": { "id": "JPSection-68" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-68-SEC3-POS11" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }] }, { "$": { "id": "JPSection-69" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-69-SEC4-POS16" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT60M"] }] }, { "$": { "id": "JPSection-70" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-70-SEC5-POS17" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT170M"] }] }, { "$": { "id": "JPSection-71" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-71-SEC3-POS10" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-72" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-72-SEC3-POS7" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-73" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-73-SEC6-POS20" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-74" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-74-SEC7-POS22" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55092"], "TimingStatus": ["PTP"] }], "RunTime": ["PT40M"] }, { "$": { "id": "JPSection-74-SEC7-POS23" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEM55092"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "RunTime": ["PT20M"] }, { "$": { "id": "JPSection-74-SEC7-POS24" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOA10663"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }, { "$": { "id": "JPSection-74-SEC7-POS25" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT50M"] }] }, { "$": { "id": "JPSection-75" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-75-SEC9-POS26" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["490014051VC"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }, { "$": { "id": "JPSection-75-SEC9-POS27" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT120M"] }, { "$": { "id": "JPSection-75-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT70M"] }, { "$": { "id": "JPSection-75-SEC9-POS28" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["setDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT9M"] }] }, { "$": { "id": "JPSection-76" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-76-SEC11-POS29" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT65M"] }] }, { "$": { "id": "JPSection-77" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-77-SEC16-POS38" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT65M"] }] }, { "$": { "id": "JPSection-78" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-78-SEC17-POS42" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }] }, { "$": { "id": "JPSection-79" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-79-SEC17-POS47" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }] }, { "$": { "id": "JPSection-80" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-80-SEC20-POS53" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT300M"] }] }, { "$": { "id": "JPSection-81" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-81-SEC21-POS54" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT85M"] }, { "$": { "id": "JPSection-81-SEC21-POS55" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }] }, { "$": { "id": "JPSection-82" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-82-SEC24-POS58" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT275M"] }] }, { "$": { "id": "JPSection-83" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-83-SEC25-POS63" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "RunTime": ["PT120M"] }] }, { "$": { "id": "JPSection-84" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-84-SEC25-POS64" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT165M"] }] }, { "$": { "id": "JPSection-85" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-85-SEC26-POS65" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT30M"] }, { "$": { "id": "JPSection-85-SEC26-POS66" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "RunTime": ["PT25M"] }, { "$": { "id": "JPSection-85-SEC26-POS67" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT110M"] }] }, { "$": { "id": "JPSection-86" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-86-SEC28-POS72" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT80M"] }] }, { "$": { "id": "JPSection-87" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-87-SEC29-POS73" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT155M"] }, { "$": { "id": "JPSection-87-SEC29-POS74" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT145M"] }] }, { "$": { "id": "JPSection-88" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-88-SEC23-POS57" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["010000036"], "TimingStatus": ["PTP"] }], "RunTime": ["PT115M"] }] }, { "$": { "id": "JPSection-89" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-89-SEC32-POS76" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["setDown"], "StopPointRef": ["490016736W"], "TimingStatus": ["PTP"] }], "RunTime": ["PT270M"] }] }, { "$": { "id": "JPSection-90" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-90-SEC33-POS77" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT15M"] }] }, { "$": { "id": "JPSection-91" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-91-SEC33-POS79" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15732"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "WaitTime": ["PT5M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT80M"] }] }, { "$": { "id": "JPSection-92" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-92-SEC33-POS80" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["1100DEC10183"], "TimingStatus": ["PTP"] }], "RunTime": ["PT65M"] }] }, { "$": { "id": "JPSection-93" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-93-SEC25-POS59" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15248"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["0800COA15596"], "TimingStatus": ["PTP"] }], "RunTime": ["PT10M"] }] }, { "$": { "id": "JPSection-94" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-94-SEC34-POS81" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUp"], "StopPointRef": ["0800COC30451"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "RunTime": ["PT40M"] }, { "$": { "id": "JPSection-94-SEC34-POS82" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUp"], "StopPointRef": ["0800COA15390"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "WaitTime": ["PT10M"], "Activity": ["pickUpAndSetDown"], "StopPointRef": ["118000037"], "TimingStatus": ["PTP"] }], "RunTime": ["PT95M"] }] }, { "$": { "id": "JPSection-95" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-95-SEC34-POS83" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUp"], "StopPointRef": ["1180033077"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUp"], "StopPointRef": ["1190TOZ00813"], "TimingStatus": ["PTP"] }], "RunTime": ["PT55M"] }] }] }], "Operators": [{ "Operator": [{ "$": { "id": "OId_MEGA" }, "OperatorCode": ["MEGA"], "OperatorShortName": ["Megabus"], "OperatorNameOnLicence": ["Stagecoach Megabus"] }] }], "Services": [{ "Service": [{ "ServiceCode": ["M6_MEGA"], "Lines": [{ "Line": [{ "$": { "id": "l_M6_MEGA" }, "LineName": ["M6"] }] }], "OperatingPeriod": [{ "StartDate": ["2018-06-24"], "EndDate": ["2099-12-31"] }], "RegisteredOperatorRef": ["OId_MEGA"], "StopRequirements": [{ "NoNewStopsRequired": [""] }], "Mode": ["coach"], "Description": ["Falmouth - Victoria,London"], "StandardService": [{ "Origin": ["Falmouth"], "Destination": ["Victoria, London"], "JourneyPattern": [{ "$": { "id": "JP366" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-45", "JPSection-66", "JPSection-17"] }, { "$": { "id": "JP367" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-46", "JPSection-67", "JPSection-18"] }, { "$": { "id": "JP368" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-15", "JPSection-68", "JPSection-13"] }, { "$": { "id": "JP369" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-16", "JPSection-69", "JPSection-14"] }, { "$": { "id": "JP370" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-70", "JPSection-23", "JPSection-71", "JPSection-3"] }, { "$": { "id": "JP371" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-72", "JPSection-24", "JPSection-73", "JPSection-4"] }, { "$": { "id": "JP372" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-49", "JPSection-74", "JPSection-47"] }, { "$": { "id": "JP373" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-19"] }, { "$": { "id": "JP375" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-75"] }, { "$": { "id": "JP376" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-20"] }, { "$": { "id": "JP378" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-50", "JPSection-76", "JPSection-48"] }, { "$": { "id": "JP379" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-1"] }, { "$": { "id": "JP380" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-5"] }, { "$": { "id": "JP382" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-2"] }, { "$": { "id": "JP383" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-6"] }, { "$": { "id": "JP384" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-51", "JPSection-77", "JPSection-21"] }, { "$": { "id": "JP385" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-52", "JPSection-78", "JPSection-9"] }, { "$": { "id": "JP386" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-25", "JPSection-54", "JPSection-79"] }, { "$": { "id": "JP387" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-7", "JPSection-56"] }, { "$": { "id": "JP388" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-26", "JPSection-80"] }, { "$": { "id": "JP389" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-53", "JPSection-81", "JPSection-36"] }, { "$": { "id": "JP390" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-27", "JPSection-57"] }, { "$": { "id": "JP391" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-28", "JPSection-39"] }, { "$": { "id": "JP392" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-8", "JPSection-82"] }, { "$": { "id": "JP393" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-43", "JPSection-41", "JPSection-83", "JPSection-34", "JPSection-84"] }, { "$": { "id": "JP394" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-44", "JPSection-85", "JPSection-60", "JPSection-35", "JPSection-58"] }, { "$": { "id": "JP395" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-11", "JPSection-61", "JPSection-33", "JPSection-59"] }, { "$": { "id": "JP396" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-12", "JPSection-86", "JPSection-40"] }, { "$": { "id": "JP397" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-29", "JPSection-87"] }, { "$": { "id": "JP398" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-30", "JPSection-55", "JPSection-37"] }, { "$": { "id": "JP399" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-31", "JPSection-88", "JPSection-38"] }, { "$": { "id": "JP400" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-32", "JPSection-89"] }, { "$": { "id": "JP402" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-90", "JPSection-64", "JPSection-42", "JPSection-91", "JPSection-62", "JPSection-92", "JPSection-22"] }, { "$": { "id": "JP404" }, "Direction": ["inbound"], "JourneyPatternSectionRefs": ["JPSection-93", "JPSection-65", "JPSection-94", "JPSection-63", "JPSection-95", "JPSection-10"] }] }] }] }], "VehicleJourneys": [{ "VehicleJourney": [{ "PrivateCode": ["0602"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToFriday": [""] }] }] }], "VehicleJourneyCode": ["0602"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP366"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["08:00:00"] }, { "PrivateCode": ["J162"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J162"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP367"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["08:00:00"] }, { "PrivateCode": ["0614"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""], "Tuesday": [""], "Wednesday": [""], "Sunday": [""] }] }] }], "VehicleJourneyCode": ["0614"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP368"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newquay to Redruth"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["12:00:00"] }, { "PrivateCode": ["J163"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Thursday": [""] }] }] }], "VehicleJourneyCode": ["J163"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP369"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newton Abbot - Torquay - Paignton"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["12:00:00"] }, { "PrivateCode": ["J164"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J164"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP370"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newton Abbot - Torquay - Paignton"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["12:00:00"] }, { "PrivateCode": ["0616"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["0616"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP371"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["13:00:00"] }, { "PrivateCode": ["0618"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }] }], "VehicleJourneyCode": ["0618"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP372"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between UWE - Bristol, Plymouth Uni - Plymouth"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["15:30:00"] }, { "PrivateCode": ["J165"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2099-12-24"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J165"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP373"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["15:30:00"] }, { "PrivateCode": ["J166"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J166"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "VehicleJourneyRef": ["0618"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["16:00:00"] }, { "PrivateCode": ["0626"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""], "Tuesday": [""], "Wednesday": [""], "Thursday": [""] }] }] }], "VehicleJourneyCode": ["0626"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP375"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["18:00:00"] }, { "PrivateCode": ["J167"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J167"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP376"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["18:00:00"] }, { "PrivateCode": ["J168"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["J168"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "VehicleJourneyRef": ["0618"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["18:00:00"] }, { "PrivateCode": ["J169"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }] }], "VehicleJourneyCode": ["J169"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP378"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["18:00:00"] }, { "PrivateCode": ["0628"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Tuesday": [""], "Wednesday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-06"] }, { "StartDate": ["2018-08-09"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["0628"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP379"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["23:30:00"] }, { "PrivateCode": ["J170"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToSunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-12"] }] }] }] }], "VehicleJourneyCode": ["J170"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP380"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["23:30:00"] }, { "PrivateCode": ["J171"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToSunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-08-07"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J171"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "VehicleJourneyRef": ["J170"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["23:30:00"] }, { "PrivateCode": ["J172"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-11"] }, { "StartDate": ["2018-08-13"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J172"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP382"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["23:30:00"] }, { "PrivateCode": ["J173"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Thursday": [""], "Friday": [""], "Saturday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-08"] }, { "StartDate": ["2018-08-12"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J173"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP383"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["23:30:00"] }, { "PrivateCode": ["0601"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToSunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-08-08"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["0601"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP384"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["01:00:00"] }, { "PrivateCode": ["J174"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-19"] }] }] }] }], "VehicleJourneyCode": ["J174"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP385"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newquay to Bodmin, Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["04:45:00"] }, { "PrivateCode": ["0613"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Tuesday": [""], "Wednesday": [""], "Thursday": [""] }] }] }], "VehicleJourneyCode": ["0613"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP386"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Paignton - Torquay - Newton Abbot, Bristol - UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["05:45:00"] }, { "PrivateCode": ["J179"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["J179"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP387"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Paignton - Torquay - Newton Abbot"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["05:00:00"] }, { "PrivateCode": ["J180"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J180"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP388"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["06:15:00"] }, { "PrivateCode": ["0617"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""] }] }] }], "VehicleJourneyCode": ["0617"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP389"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["07:30:00"] }, { "PrivateCode": ["J181"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["J181"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP390"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Redruth to Newquay"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["08:15:00"] }, { "PrivateCode": ["J182"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2099-12-24"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J182"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP391"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["08:15:00"] }, { "PrivateCode": ["0619"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }] }], "VehicleJourneyCode": ["0619"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP392"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["10:45:00"] }, { "PrivateCode": ["0627"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["0627"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP393"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["09:05:00"] }, { "PrivateCode": ["J183"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["J183"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP394"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["09:05:00"] }, { "PrivateCode": ["J184"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""], "Tuesday": [""], "Wednesday": [""], "Thursday": [""] }] }] }], "VehicleJourneyCode": ["J184"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP395"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["09:45:00"] }, { "PrivateCode": ["J185"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }] }], "VehicleJourneyCode": ["J185"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP396"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["10:45:00"] }, { "PrivateCode": ["0633"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Friday": [""] }] }] }], "VehicleJourneyCode": ["0633"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP397"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["15:30:00"] }, { "PrivateCode": ["J186"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""], "Tuesday": [""], "Wednesday": [""], "Thursday": [""] }] }] }], "VehicleJourneyCode": ["J186"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP398"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["15:40:00"] }, { "PrivateCode": ["J187"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Saturday": [""] }] }] }], "VehicleJourneyCode": ["J187"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP399"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["15:40:00"] }, { "PrivateCode": ["J188"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }] }], "VehicleJourneyCode": ["J188"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP400"], "Note": [{ "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["16:20:00"] }, { "PrivateCode": ["J175"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToSunday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-09"] }] }] }] }], "VehicleJourneyCode": ["J175"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "VehicleJourneyRef": ["0601"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["01:00:00"] }, { "PrivateCode": ["J176"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Tuesday": [""], "Wednesday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-06"] }, { "StartDate": ["2018-08-09"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J176"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP402"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["22:00:00"] }, { "PrivateCode": ["J177"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-08-08"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J177"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "VehicleJourneyRef": ["J174"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newquay to Bodmin, Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["04:45:00"] }, { "PrivateCode": ["J178"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["COACH"], "Description": ["COACH"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Monday": [""] }] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-06-24"], "EndDate": ["2018-08-12"] }, { "StartDate": ["2018-08-14"], "EndDate": ["2099-12-31"] }] }] }] }], "VehicleJourneyCode": ["J178"], "ServiceRef": ["M6_MEGA"], "LineRef": ["l_M6_MEGA"], "JourneyPatternRef": ["JP404"], "Note": [{ "NoteCode": ["note1"], "NoteText": ["No tickets sold between Newquay to Bodmin, Bristol to UWE"] }, { "NoteCode": ["MB1"], "NoteText": ["Book at megabus.com or 0900 1600900 (65p/min + network charges)"] }], "DepartureTime": ["01:45:00"] }] }] } };
const example2 = { "TransXChange": { "$": { "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance", "xmlns:xsd": "http://www.w3.org/2001/XMLSchema", "xsi:schemaLocation": "http://www.transxchange.org.uk/ http://www.transxchange.org.uk/schema/2.1/TransXChange_general.xsd", "CreationDateTime": "2018-09-20T13:09:14.2891416+01:00", "ModificationDateTime": "2018-09-20T13:09:14.2891416+01:00", "Modification": "new", "RevisionNumber": "1", "FileName": "TXC.xml", "SchemaVersion": "2.1", "RegistrationDocument": "false", "xmlns": "http://www.transxchange.org.uk/" }, "StopPoints": [{ "AnnotatedStopPointRef": [{ "StopPointRef": ["2800S42023I"], "CommonName": ["Queen Square Bus Station"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42053E"], "CommonName": ["Metropolitan Cathedral"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42051A"], "CommonName": ["Adelphi Hotel"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42063A"], "CommonName": ["World Museum"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41157B"], "CommonName": ["Pilgrim Street"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41186A"], "CommonName": ["Salthouse Quay"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42088A"], "CommonName": ["Brunswick Street"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41228B"], "CommonName": ["Exhibition Centre Liverpool"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42079B"], "CommonName": ["Temple Lane"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41200B"], "CommonName": ["Arrad Street"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41050A"], "CommonName": ["Bold Place"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S42022B"], "CommonName": ["North John Street"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }, { "StopPointRef": ["2800S41049B"], "CommonName": ["Upper Duke Street"], "LocalityName": ["Liverpool"], "LocalityQualifier": ["Liverpool"] }] }], "JourneyPatternSections": [{ "JourneyPatternSection": [{ "$": { "id": "JPSection-1" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-1-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-1-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-1-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-1-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-2" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-2-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-2-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-2-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-2-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-3" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-3-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-3-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-3-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-3-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-4" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-4-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-4-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-4-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-4-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-5" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-5-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-5-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-5-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-5-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-6" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-6-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-6-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-6-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-6-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-7" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-7-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-7-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-7-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-7-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-8" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-8-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-8-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-8-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-8-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }] }], "Operators": [{ "Operator": [{ "$": { "id": "OId_2357" }, "NationalOperatorCode": ["MAGH"], "OperatorCode": ["2357"], "OperatorShortName": ["2357"] }] }], "Services": [{ "Service": [{ "ServiceCode": ["NW_06_2357_101_1"], "Lines": [{ "Line": [{ "$": { "id": "l_101_2357" }, "LineName": ["101"] }] }], "OperatingPeriod": [{ "StartDate": ["2018-09-03"], "EndDate": ["2018-12-31"] }], "RegisteredOperatorRef": ["OId_2357"], "StopRequirements": [{ "NoNewStopsRequired": [""] }], "Mode": ["bus"], "Description": ["LIVERPOOL - LIVERPOOL - LIVERPOOL"], "StandardService": [{ "Origin": ["Liverpool"], "Destination": ["Liverpool"], "JourneyPattern": [{ "$": { "id": "JP1" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-1"] }, { "$": { "id": "JP3" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-5"] }, { "$": { "id": "JP181" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-2"] }, { "$": { "id": "JP182" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-6"] }, { "$": { "id": "JP193" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-3"] }, { "$": { "id": "JP195" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-7"] }, { "$": { "id": "JP263" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-4"] }, { "$": { "id": "JP264" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-8"] }] }] }] }], "VehicleJourneys": [{ "VehicleJourney": [{ "PrivateCode": ["J78"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["BUS"], "Description": ["BUS"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [""] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-10-29"], "EndDate": ["2018-12-31"] }] }] }], "BankHolidayOperation": [{ "DaysOfOperation": [{ "AllBankHolidays": [""] }] }] }], "VehicleJourneyCode": ["J78"], "ServiceRef": ["NW_06_2357_101_1"], "LineRef": ["l_101_2357"], "VehicleJourneyRef": ["101"], "Note": [{ "NoteCode": ["TourA"], "NoteText": ["City Explorer open-top tour. Tour operator tickets only are valid on thi"] }], "DepartureTime": ["10:00:00"] }] }] } };
const example3 = { "TransXChange": { "$": { "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance", "xmlns:xsd": "http://www.w3.org/2001/XMLSchema", "xsi:schemaLocation": "http://www.transxchange.org.uk/ http://www.transxchange.org.uk/schema/2.1/TransXChange_general.xsd", "CreationDateTime": "2018-09-20T13:09:14.2891416+01:00", "ModificationDateTime": "2018-09-20T13:09:14.2891416+01:00", "Modification": "new", "RevisionNumber": "1", "FileName": "TXC.xml", "SchemaVersion": "2.1", "RegistrationDocument": "false", "xmlns": "http://www.transxchange.org.uk/" }, "StopPoints": [{ "StopPoint": [{ "AtcoCode": ["2800S42023I"], "Descriptor": [{ "CommonName": ["Queen Square Bus Station"] }] }, { "AtcoCode": ["2800S42053E"], "Descriptor": [{ "CommonName": ["Metropolitan Cathedral"] }] }, { "AtcoCode": ["2800S42051A"], "Descriptor": [{ "CommonName": ["Adelphi Hotel"] }] }, { "AtcoCode": ["2800S42063A"], "Descriptor": [{ "CommonName": ["World Museum"] }] }, { "AtcoCode": ["2800S41157B"], "Descriptor": [{ "CommonName": ["Pilgrim Street"] }] }, { "AtcoCode": ["2800S41186A"], "Descriptor": [{ "CommonName": ["Salthouse Quay"] }] }, { "AtcoCode": ["2800S42088A"], "Descriptor": [{ "CommonName": ["Brunswick Street"] }] }, { "AtcoCode": ["2800S41228B"], "Descriptor": [{ "CommonName": ["Exhibition Centre Liverpool"] }] }, { "AtcoCode": ["2800S42079B"], "Descriptor": [{ "CommonName": ["Temple Lane"] }] }, { "AtcoCode": ["2800S41200B"], "Descriptor": [{ "CommonName": ["Arrad Street"] }] }, { "AtcoCode": ["2800S41050A"], "Descriptor": [{ "CommonName": ["Bold Place"] }] }, { "AtcoCode": ["2800S42022B"], "Descriptor": [{ "CommonName": ["North John Street"] }] }, { "AtcoCode": ["2800S41049B"], "Descriptor": [{ "CommonName": ["Upper Duke Street"] }] }] }], "JourneyPatternSections": [{ "JourneyPatternSection": [{ "$": { "id": "JPSection-1" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-1-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-1-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-1-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-1-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-1-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-2" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-2-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-2-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-2-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-2-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-2-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-3" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-3-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-3-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-3-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-3-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-3-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-4" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-4-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-4-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS10" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-4-SEC1-POS11" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-4-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-4-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-5" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-5-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-5-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-5-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-5-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-5-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-6" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-6-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-6-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-6-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-6-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-6-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-7" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-7-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-7-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-7-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-7-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-7-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }, { "$": { "id": "JPSection-8" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPSection-8-SEC1-POS1" }, "From": [{ "$": { "SequenceNumber": "1" }, "Activity": ["pickUp"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS2" }, "From": [{ "$": { "SequenceNumber": "2" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42088A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS3" }, "From": [{ "$": { "SequenceNumber": "3" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42022B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS4" }, "From": [{ "$": { "SequenceNumber": "4" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42079B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS5" }, "From": [{ "$": { "SequenceNumber": "5" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42063A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS6" }, "From": [{ "$": { "SequenceNumber": "6" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42023I"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS7" }, "From": [{ "$": { "SequenceNumber": "7" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42051A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS8" }, "From": [{ "$": { "SequenceNumber": "8" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S42053E"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT3M"] }, { "$": { "id": "JPSection-8-SEC1-POS9" }, "From": [{ "$": { "SequenceNumber": "9" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41200B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC2-POS14" }, "From": [{ "$": { "SequenceNumber": "10" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41157B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT2M"] }, { "$": { "id": "JPSection-8-SEC2-POS15" }, "From": [{ "$": { "SequenceNumber": "11" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41050A"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT5M"] }, { "$": { "id": "JPSection-8-SEC1-POS12" }, "From": [{ "$": { "SequenceNumber": "12" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41049B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "RunTime": ["PT4M"] }, { "$": { "id": "JPSection-8-SEC1-POS13" }, "From": [{ "$": { "SequenceNumber": "13" }, "Activity": ["pickUpAndSetDown"], "StopPointRef": ["2800S41228B"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "SequenceNumber": "14" }, "Activity": ["setDown"], "StopPointRef": ["2800S41186A"], "TimingStatus": ["PTP"] }], "RunTime": ["PT1M"] }] }] }], "Operators": [{ "Operator": [{ "$": { "id": "OId_2357" }, "NationalOperatorCode": ["MAGH"], "OperatorCode": ["2357"], "OperatorShortName": ["2357"] }] }], "Services": [{ "Service": [{ "ServiceCode": ["NW_06_2357_101_1"], "Lines": [{ "Line": [{ "$": { "id": "l_101_2357" }, "LineName": ["101"] }] }], "OperatingPeriod": [{ "StartDate": ["2018-09-03"], "EndDate": ["2018-12-31"] }], "RegisteredOperatorRef": ["OId_2357"], "StopRequirements": [{ "NoNewStopsRequired": [""] }], "Mode": ["bus"], "Description": ["LIVERPOOL - LIVERPOOL - LIVERPOOL"], "StandardService": [{ "Origin": ["Liverpool"], "Destination": ["Liverpool"], "JourneyPattern": [{ "$": { "id": "JP1" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-1"] }, { "$": { "id": "JP3" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-5"] }, { "$": { "id": "JP181" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-2"] }, { "$": { "id": "JP182" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-6"] }, { "$": { "id": "JP193" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-3"] }, { "$": { "id": "JP195" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-7"] }, { "$": { "id": "JP263" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-4"] }, { "$": { "id": "JP264" }, "Direction": ["outbound"], "JourneyPatternSectionRefs": ["JPSection-8"] }] }] }] }], "VehicleJourneys": [{ "VehicleJourney": [{ "PrivateCode": ["J78"], "Operational": [{ "VehicleType": [{ "VehicleTypeCode": ["BUS"], "Description": ["BUS"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [""] }], "SpecialDaysOperation": [{ "DaysOfNonOperation": [{ "DateRange": [{ "StartDate": ["2018-10-29"], "EndDate": ["2018-12-31"] }] }] }], "BankHolidayOperation": [{ "DaysOfOperation": [{ "AllBankHolidays": [""] }] }] }], "VehicleJourneyCode": ["J78"], "ServiceRef": ["NW_06_2357_101_1"], "LineRef": ["l_101_2357"], "VehicleJourneyRef": ["101"], "Note": [{ "NoteCode": ["TourA"], "NoteText": ["City Explorer open-top tour. Tour operator tickets only are valid on thi"] }], "DepartureTime": ["10:00:00"] }] }] } };
const example4 = { "TransXChange": { "$": { "CreationDateTime": "2020-10-27T08:52:37", "ModificationDateTime": "2020-10-27T08:52:37", "Modification": "revise", "RevisionNumber": "1", "FileName": "FMAN_Oldham_Mapped_201011_FMAN006A.xml", "xsi:schemaLocation": "http://www.transxchange.org.uk/ http://www.transxchange.org.uk/schema/2.1/TransXChange_general.xsd", "SchemaVersion": "2.1", "RegistrationDocument": "false", "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance", "xmlns": "http://www.transxchange.org.uk/" }, "StopPoints": [{ "AnnotatedStopPointRef": [{ "StopPointRef": ["1800NE33001"], "CommonName": ["The Strand"] }, { "StopPointRef": ["1800NE32981"], "CommonName": ["Hogarth Road"] }] }], "RouteSections": [{ "RouteSection": [{ "$": { "id": "RS1" }, "RouteLink": [{ "$": { "id": "RL1" }, "From": [{ "StopPointRef": ["1800NE33001"] }], "To": [{ "StopPointRef": ["1800NE32981"] }], "Distance": ["294"], "Direction": ["outbound"], "Track": [{ "Mapping": [{ "Location": [{ "$": { "id": "L1" }, "Translation": [{ "Easting": ["389681"], "Northing": ["410840"], "Longitude": ["-2.157373559"], "Latitude": ["53.594039064"] }] }, { "$": { "id": "L18" }, "Translation": [{ "Easting": ["389946"], "Northing": ["410799"], "Longitude": ["-2.153357975"], "Latitude": ["53.593675146"] }] }] }] }] }] }] }], "Routes": [{ "Route": [{ "$": { "id": "RT1" }, "PrivateCode": ["FMAN006A-1"], "Description": ["The Strand - Rochdale Interchange"], "RouteSectionRef": ["RS1"] }] }], "JourneyPatternSections": [{ "JourneyPatternSection": [{ "$": { "id": "JPS1" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPTL1" }, "From": [{ "$": { "id": "JPSU1", "SequenceNumber": "15" }, "StopPointRef": ["1800NE33001"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "id": "JPSU2", "SequenceNumber": "16" }, "StopPointRef": ["1800NE49721"], "TimingStatus": ["OTH"] }], "RouteLinkRef": ["RL1"], "RunTime": ["PT0S"] }] }] }], "Operators": [{ "LicensedOperator": [{ "$": { "id": "O56" }, "NationalOperatorCode": ["FMAN"], "OperatorCode": ["FMAN"], "OperatorShortName": ["First"], "OperatorNameOnLicence": [{ "_": "First Manchester Limited", "$": { "xml:lang": "en" } }], "TradingName": ["First Manchester"], "LicenceNumber": ["PC0003680"], "LicenceClassification": ["standardNational"], "EnquiryTelephoneNumber": [{ "TelNationalNumber": ["01616277217"] }], "ContactTelephoneNumber": [{ "TelNationalNumber": ["01616277217"] }], "OperatorAddresses": [{ "CorrespondenceAddress": [{ "$": { "xmlns:apd": "http://www.govtalk.gov.uk/people/AddressAndPersonalDetails" }, "apd:Line": ["Wallshaw Street", "Oldham"], "apd:PostCode": ["OL1 3TR"] }] }], "Garages": [{ "Garage": [{ "GarageCode": ["OM"], "GarageName": [{ "_": "Oldham Depot", "$": { "xml:lang": "en" } }] }, { "GarageCode": ["FG"], "GarageName": [{ "_": "Vantage Depot", "$": { "xml:lang": "en" } }] }] }] }] }], "Services": [{ "Service": [{ "ServiceCode": ["FMAN006A"], "PrivateCode": ["FMAN006A"], "Lines": [{ "Line": [{ "$": { "id": "SL1" }, "LineName": ["6"] }] }], "OperatingPeriod": [{ "StartDate": ["2020-10-11"] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToSunday": [""] }] }] }], "RegisteredOperatorRef": ["O56"], "StopRequirements": [{ "NoNewStopsRequired": [""] }], "Mode": ["bus"], "Description": ["Rochdale - Kirkholt  "], "StandardService": [{ "Origin": ["Rochdale"], "Destination": ["Kirkholt"], "JourneyPattern": [{ "$": { "id": "JP1" }, "DestinationDisplay": ["Rochdale"], "Direction": ["outbound"], "Description": ["The Strand - Rochdale Interchange"], "RouteRef": ["RT1"], "JourneyPatternSectionRefs": ["JPS1"] }] }], "Direction": ["outbound"] }] }], "VehicleJourneys": [{ "VehicleJourney": [{ "$": { "SequenceNumber": "1" }, "PrivateCode": ["006MFFM1:O:1"], "Operational": [{ "Block": [{ "Description": ["351"], "BlockNumber": ["351"] }], "TicketMachine": [{ "JourneyCode": ["0001"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "MondayToFriday": [""] }] }], "BankHolidayOperation": [{ "DaysOfNonOperation": [{ "GoodFriday": [""], "LateSummerBankHolidayNotScotland": [""], "MayDay": [""], "EasterMonday": [""], "SpringBank": [""] }] }] }], "GarageRef": ["OM"], "VehicleJourneyCode": ["VJ1"], "ServiceRef": ["FMAN006A"], "LineRef": ["SL1"], "JourneyPatternRef": ["JP1"], "DepartureTime": ["05:39:00"] }] }] } };
const example5 = { "TransXChange": { "$": { "CreationDateTime": "2020-10-27T08:52:37", "ModificationDateTime": "2020-10-27T08:52:37", "Modification": "revise", "RevisionNumber": "1", "FileName": "FMAN_Oldham_Mapped_201011_FMAN006A.xml", "xsi:schemaLocation": "http://www.transxchange.org.uk/ http://www.transxchange.org.uk/schema/2.1/TransXChange_general.xsd", "SchemaVersion": "2.1", "RegistrationDocument": "false", "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance", "xmlns": "http://www.transxchange.org.uk/" }, "StopPoints": [{ "AnnotatedStopPointRef": [{ "StopPointRef": ["1800NE33001"], "CommonName": ["The Strand"] }, { "StopPointRef": ["1800NE32981"], "CommonName": ["Hogarth Road"] }] }], "RouteSections": [{ "RouteSection": [{ "$": { "id": "RS1" }, "RouteLink": [{ "$": { "id": "RL1" }, "From": [{ "StopPointRef": ["1800NE33001"] }], "To": [{ "StopPointRef": ["1800NE32981"] }], "Distance": ["294"], "Direction": ["outbound"], "Track": [{ "Mapping": [{ "Location": [{ "$": { "id": "L1" }, "Translation": [{ "Easting": ["389681"], "Northing": ["410840"], "Longitude": ["-2.157373559"], "Latitude": ["53.594039064"] }] }, { "$": { "id": "L18" }, "Translation": [{ "Easting": ["389946"], "Northing": ["410799"], "Longitude": ["-2.153357975"], "Latitude": ["53.593675146"] }] }] }] }] }] }] }], "Routes": [{ "Route": [{ "$": { "id": "RT1" }, "PrivateCode": ["FMAN006A-1"], "Description": ["The Strand - Rochdale Interchange"], "RouteSectionRef": ["RS1"] }] }], "JourneyPatternSections": [{ "JourneyPatternSection": [{ "$": { "id": "JPS1" }, "JourneyPatternTimingLink": [{ "$": { "id": "JPTL1" }, "From": [{ "$": { "id": "JPSU1", "SequenceNumber": "15" }, "StopPointRef": ["1800NE33001"], "TimingStatus": ["PTP"] }], "To": [{ "$": { "id": "JPSU2", "SequenceNumber": "16" }, "StopPointRef": ["1800NE49721"], "TimingStatus": ["OTH"] }], "RouteLinkRef": ["RL1"], "RunTime": ["PT0S"] }] }] }], "Operators": [{ "LicensedOperator": [{ "$": { "id": "O56" }, "NationalOperatorCode": ["FMAN"], "OperatorCode": ["FMAN"], "OperatorShortName": ["First"], "OperatorNameOnLicence": [{ "_": "First Manchester Limited", "$": { "xml:lang": "en" } }], "TradingName": ["First Manchester"], "LicenceNumber": ["PC0003680"], "LicenceClassification": ["standardNational"], "EnquiryTelephoneNumber": [{ "TelNationalNumber": ["01616277217"] }], "ContactTelephoneNumber": [{ "TelNationalNumber": ["01616277217"] }], "OperatorAddresses": [{ "CorrespondenceAddress": [{ "$": { "xmlns:apd": "http://www.govtalk.gov.uk/people/AddressAndPersonalDetails" }, "apd:Line": ["Wallshaw Street", "Oldham"], "apd:PostCode": ["OL1 3TR"] }] }], "Garages": [{ "Garage": [{ "GarageCode": ["OM"], "GarageName": [{ "_": "Oldham Depot", "$": { "xml:lang": "en" } }] }, { "GarageCode": ["FG"], "GarageName": [{ "_": "Vantage Depot", "$": { "xml:lang": "en" } }] }] }] }] }], "Services": [{ "Service": [{ "ServiceCode": ["FMAN006A"], "PrivateCode": ["FMAN006A"], "Lines": [{ "Line": [{ "$": { "id": "SL1" }, "LineName": ["6"] }] }], "OperatingPeriod": [{ "StartDate": ["2020-10-11"] }], "RegisteredOperatorRef": ["O56"], "StopRequirements": [{ "NoNewStopsRequired": [""] }], "Mode": ["bus"], "Description": ["Rochdale - Kirkholt  "], "StandardService": [{ "Origin": ["Rochdale"], "Destination": ["Kirkholt"], "JourneyPattern": [{ "$": { "id": "JP1" }, "DestinationDisplay": ["Rochdale"], "Direction": ["outbound"], "Description": ["The Strand - Rochdale Interchange"], "RouteRef": ["RT1"], "JourneyPatternSectionRefs": ["JPS1"] }] }], "Direction": ["outbound"] }] }], "VehicleJourneys": [{ "VehicleJourney": [{ "$": { "SequenceNumber": "1" }, "PrivateCode": ["006MFFM1:O:1"], "Operational": [{ "Block": [{ "Description": ["351"], "BlockNumber": ["351"] }], "TicketMachine": [{ "JourneyCode": ["0001"] }] }], "OperatingProfile": [{ "RegularDayType": [{ "DaysOfWeek": [{ "Sunday": [""] }] }], "BankHolidayOperation": [{ "DaysOfOperation": [{ "GoodFriday": [""], "LateSummerBankHolidayNotScotland": [""], "MayDay": [""], "EasterMonday": [""], "SpringBank": [""], "OtherPublicHoliday": [{ "Description": ["Platinum Jubilee bank holiday"], "Date": ["2022-06-03"] }] }], "DaysOfNonOperation": [{ "Christmas": [""], "NewYearsDay": [""], "ChristmasDayHoliday": [""], "BoxingDayHoliday": [""], "NewYearsDayHoliday": [""] }] }] }], "GarageRef": ["OM"], "VehicleJourneyCode": ["VJ1"], "ServiceRef": ["FMAN006A"], "LineRef": ["SL1"], "JourneyPatternRef": ["JP1"], "DepartureTime": ["05:39:00"] }] }] } };
